pub enum CapabilityError {
AgreedButNoKey {
agree_var: String,
key_var: String,
},
KeyButNotAgreed {
agree_var: String,
},
}Expand description
Errors that can arise during CapabilityProfile::from_env.
Variants
AgreedButNoKey
User set the agree env var but provided no key. See docs/CAPABILITY.md 2.
Fields
KeyButNotAgreed
Key env var is set but user has not agreed. See docs/CAPABILITY.md 2.